@@ -38,7 +38,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '1.6';
+our $VERSION = '1.7';
 
 
 our $EVENT_NONE = 0;
@@ -169,17 +169,19 @@ Net::Gadu - Interfejs do biblioteki libgadu.so dla protokou Gadu-Gadu
 
 Wykorzystuje bibliotek libgadu.so ktra jest czesci projektu EKG.
 Aby zaintalowa libgadu.so naley skompilowa EKG z opcj --with-shared. Jeli uywasz EKG z pakietu prawdopodobnie
-biblioteka ta zostaa zainstalowana. Szczegowe informacje znajdziesz na stronie projektu EKG - http://dev.null.pl/ekg/
+biblioteka ta zostaa zainstalowana. Szczegowe informacje znajdziesz na stronie projektu EKG - http://ekg.chmurka.net/
 Do zbudowania pakietu potrzeba jest zainstalowana biblioteka z prefixem /usr lub /usr/local , jesli lokalizacja jest niestandardowa mozna wyedytowac plik Makefile.PL podajac wlasciwe lokalizacje
 
 =head1 DOWNLOAD
 
-http://search.cpan.org/CPAN/authors/id/K/KR/KRZAK/
+http://www.cpan.org/modules/by-module/Net/Net-Gadu-1.7.tar.gz
+
 
 =head1 SUBVERSION
 
 $ svn co http://svn.hakore.com/netgadu/trunk
 
+
 =head1 METHODS
 
 Dostepne metody :
@@ -359,7 +361,7 @@ Zmiana statusu z opisem, moliwa na jeden z:
 
 =head1 AUTHOR
 
-Marcin Krzyanowski, http://hakore.com/
+Marcin Krzyanowski, http://www.hakore.com/
 
 =head1 LICENCE
 
@@ -368,8 +370,8 @@ Lesser General Public License
 =head1 SEE ALSO
 
     http://www.gadu-gadu.pl/
-    http://www.gnugadu.org/
     http://ekg.chmurka.net/
+    http://www.gnugadu.org/
     http://www.hakore.com/
 
 =cut
